@@ -609,9 +609,10 @@ def robotest(config, file, user, all, tag, test_name, param):
     if failds:
         sys.exit(-1)
 
-def _get_all_unittest_files(all_files=False):
+def _get_all_unittest_files(config, all_files=False):
     from .odoo_config import MANIFEST, MANIFEST_FILE
     from .module_tools import Module
+    from .odoo_config import customs_dir
     testfiles = []
 
     if not all_files:
@@ -621,7 +622,12 @@ def _get_all_unittest_files(all_files=False):
                 testfiles.append(_file.relative_to(MANIFEST_FILE().parent))
                 del _file
     else:
-        raise Exception('needs implementation')
+
+        modules = __get_installed_modules(config)
+        for file in customs_dir().glob("**/tests/test*.py"):
+            module_name = file.parent.parent.name
+            if module_name in modules:
+                testfiles.append(file.relative_to(MANIFEST_FILE().parent))
     return testfiles
 
 def _get_all_robottest_files():
@@ -641,7 +647,7 @@ def _get_all_robottest_files():
 @click.option('-a', '--all', is_flag=True)
 @pass_config
 def list_unit_test_files(config, all):
-    files = _get_all_unittest_files(all_files=all)
+    files = _get_all_unittest_files(config, all_files=all)
     click.secho("!!!")
     for file in files:
         click.secho(file)
@@ -671,7 +677,7 @@ def unittest(config, repeat, file, remote_debug, wait_for_remote):
     from pathlib import Path
     last_unittest = config.runtime_settings.get('last_unittest')
 
-    testfiles = _get_all_unittest_files(all_files=True)
+    testfiles = _get_all_unittest_files(config, all_files=True)
 
     if file:
         if '/' in file:
